//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr 1998
// 
// uIOcntl.cc -- 
// 
// Author           : Peter A. Buhr
// Created On       : Wed Jun 10 16:11:30 1998
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Sep  6 11:36:46 2007
// Update Count     : 21
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#define __U_KERNEL__
#include <uC++.h>
//#include <uDebug.h>
#include <uIOcntl.h>


int uIOClosure::wrapper( int rwe ) {
    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.setPollFlag( access.fd );
    for ( ;; ) {
	retcode = action( rwe );
      if ( retcode != -1 || errno != EINTR ) break;	// timer interrupt ?
    } // for
    int terrno = errno;					// preserve errno across calls
    if ( access.poll.getStatus() == uPoll::PollOnDemand ) access.poll.clearPollFlag( access.fd );
    errno = terrno;

    return retcode;
} // uIOClosure::wrapper


// Local Variables: //
// compile-command: "gmake install" //
// End: //
